districtsTK
=======================

This module is used to determine, whether or not a point on earth is within a given district.

Needs a GeoJSON file to get the data from. This is the only parameter, if it's run as an executable.
e.g.: python3 districtsTk.py my/favourite/cities/geo.json
